// Copyright (C) Chris Pudney, The University of Western Australia, 1998.
// All rights reserved.
//  
// Permission to use, copy, modify and distribute this software and its
// documentation only for the purposes of teaching and research is hereby
// granted without fee, provided that the above copyright notice and this
// permission notice appear in all copies of this software/documentation
// and that you do not sell the software.  No commercial use or
// distribution of the software is permitted without the consent of the
// copyright owners.  Commercial licensing is available by contacting the
// author(s).
// 
// THIS SOFTWARE/DOCUMENTATION IS PROVIDED WITH NO WARRANTY, EXPRESS OR
// IMPLIED, INCLUDING, WITHOUT LIMITATION, WARRANTY OF MERCHANTABILITY OR
// FITNESS FOR A PARTICULAR PURPOSE.

import java.io.*;
import java.util.*;


/**
 * A class defining the main program for convex hull construction.
 * 
 * @author  Chris Pudney <mailto:cpudney@alphapharm.pharm.uwa.edu.au>
 * @version 1.1
 * @see     ConvexHull
 */
public class Hull
{
  /**
   * The main program that reads a file containing a list of 3D points,
   * constructs their convex hull, and writes it to a file in the OFF
   * format.
   *
   * usage: Hull infile outfile
   *
   * @param args  command-line arguments
   * @exception ConvexHullException
   *            if hull construction fails.
   */
  public static void main(String[] args)
    throws IOException, ConvexHullException
      {
	if (args.length != 2)
	  {
	    System.out.println("usage: Hull <infile> <outfile>");
	  }
	else
	  {
	    BufferedReader r = new BufferedReader(new FileReader(args[0]));
	    StreamTokenizer st = new StreamTokenizer(r);
	    Vector vertices = new Vector();

	    /* Read vertices */
	    while ( st.nextToken() != st.TT_EOF )
	      {
		int x = 0, y = 0, z = 0;

		if (st.ttype == st.TT_NUMBER)
		  {
		    x = (int)st.nval;
		  }
		else
		  {
		    System.out.println("Error reading " + args[0]);
		    System.exit(-1);
		  }
		if (st.nextToken() == st.TT_NUMBER)
		  {
		    y = (int)st.nval;
		  }
		else
		  {
		    System.out.println("Error reading " + args[0]);
		    System.exit(-1);
		  }
		if (st.nextToken() == st.TT_NUMBER)
		  {
		    z = (int)st.nval;
		  }	
		else
		  {
		    System.out.println("Error reading " + args[0]);
		    System.exit(-1);
		  }
		vertices.addElement(new Vertex(x, y, z));
	      }
	    r.close();

	    ConvexHull hull = new ConvexHull(vertices);

	    PrintWriter pw = new PrintWriter
	      (new BufferedWriter(new FileWriter(args[1])));
	    hull.writeOFF(pw);
	    pw.close();
	  }
      }
}
